@@ -2,13 +2,17 @@
 function(object,digits=4,...) {
 
 cat("", "\n")
-cat("Alternative hypotheses: ratios ")
-if (is.numeric(object$margin.lo)) cat("larger than", object$margin.lo)
-if (is.numeric(object$margin.lo) & is.numeric(object$margin.up)) cat(" and ")
-if (is.numeric(object$margin.up)) cat ("smaller than", object$margin.up)
+cat("Alternative hypotheses: ratios")
+if (is.numeric(object$margin.lo)) cat(" larger than", object$margin.lo)
+if (is.numeric(object$margin.lo) & is.numeric(object$margin.up)) cat(" and")
+if (is.numeric(object$margin.up)) cat (" smaller than", object$margin.up)
 cat("", "\n")
+cat("Comparison:", object$comp.name,
+    "\n")
 cat("Method:", object$method,
     "\n")
+cat("Equal variances: ", object$var.equal,
+    "\n")
 cat("", "\n")
 cat("Degree of freedom:", "\n")
 print(object$degr.fr, digits=digits)
